# slack_transfer
[![python](https://img.shields.io/pypi/pyversions/slack-transfer.svg)](https://pypi.org/project/slack-transfer)
[![pypi](https://img.shields.io/pypi/v/slack-transfer.svg)](https://pypi.org/project/slack-transfer)
[![CI](https://github.com/masanorihirano/slack_transfer/actions/workflows/ci.yml/badge.svg)](https://github.com/masanorihirano/slack_transfer/actions/workflows/ci.yml)
[![downloads](https://img.shields.io/pypi/dm/slack-transfer)](https://pypi.org/project/slack-transfer)
[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/d8c6e7691ae4462592be32394699b09c)](https://www.codacy.com/gh/masanorihirano/slack_transfer/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=masanorihirano/slack_transfer&amp;utm_campaign=Badge_Grade)

## Documentations & User Guides
slack_transfer is a tool for transferring messages to the other slack workspace.

Documentations are available on [readthedoc](https://slack-transfer.readthedocs.io).
-   [User guide (en)](https://slack-transfer.readthedocs.io/en/latest/user_guide/index.html)
-   [ユーザーガイド (日本語)](https://slack-transfer.readthedocs.io/en/latest/user_guide/index_ja.html)

## Install
This package is available on pypi as [`slack-transfer`](https://pypi.org/project/slack-transfer/)
```bash
$ pip install slack-transfer
$ python
>> import slack_transfer
```
Please note that you have to user `slack_transfer` instead of `slack-transfer` for importing.

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/masanorihirano/slack_transfer/blob/main/examples/slack_transfer.ipynb)

## Issues and Contribution
About issues (bugs):
-   You can report issues [here](https://github.com/masanorihirano/slack_transfer/issues).
-   日本語でissueを立てて構いません．
-   There are no guarantee to support or fix those issues.

Contributions:
-   You can send pull requests (PRs) to this repository.
-   But, there are no guarantee to merge your PRs.
